-- Some common queries

-- A few on db type; 
-- am I a member db?
select is_federation_member 
from sys.databases where name=db_name()

-- am I a root db?
select (~ is_federation_member) & (select cast(count(*) as bit) 
from sys.federations)  from sys.databases where name=db_name()

-- am I a db but not a root?
select (~ is_federation_member) & ( select ~ cast(count(*) as bit) 
from sys.federations)  from sys.databases where name=db_name() 
go

-- federation information for root dbs;
-- count of members each federation contain?
use federation root with reset
GO
select f.name, count(fm.member_id) 
from sys.federations f 
join sys.federation_members fm 
on f.federation_id=fm.federation_id group by f.name
GO

-- for members dbs;
use federation CustomerFederation(cid = 0) WITH RESET, FILTERING=OFF
GO

-- which federation is this member a part of?
select * from sys.federations 
where (select is_federation_member 
  from sys.databases 
  where name=db_name())=1
GO
-- what are my low and high ranges?
select range_low, range_high from sys.federation_member_distributions
GO
-- what is member db name and root db name?
select db_name()
go
use federation root with reset
go
select db_name()
go

-- when were my federations created?
select federation_id, name, create_date 
from sys.federation_history 
where drop_date is NULL
go 

-- Which federation member held id=55 2 minutes ago in 'CustomerFederation'?
select dateadd(mi,-2,getutcdate()),f.name,fmdh.* 
from sys.federation_member_distribution_history fmdh 
join sys.federation_history f 
on fmdh.federation_id=f.federation_id
where  f.name='CustomerFederation'
    AND 55 between cast(range_low as bigint) and cast(range_high as bigint)
    AND ((fmdh.drop_date is not null AND 
          dateadd(mi,-5,getutcdate()) between fmdh.create_date and fmdh.drop_date)
        OR (fmdh.drop_date is null AND 
          dateadd(mi,-5,getutcdate())>fmdh.create_date)
        )
GO

-- see how long a repartitioning operation has been active
select datediff(ss,start_date,getutcdate()) as total_seconds, percent_complete, *
from sys.dm_federation_operations
GO

-- display members with active federation repartitioning operations
SELECT fmc.member_id, 
  cast(fmc.range_low as nvarchar) range_low, 
  cast(fmc.range_high as nvarchar) range_high, 
  fops.federation_operation_type
FROM sys.federations f 
JOIN sys.federation_member_distributions fmc 
ON f.federation_id=fmc.federation_id 
LEFT OUTER JOIN (
 SELECT fo.federation_id, fom.member_id, 
    fo.federation_operation_type, fom.member_type
 FROM sys.dm_federation_operation_members fom 
 JOIN sys.dm_federation_operations fo
 ON fo.federation_operation_id = fom.federation_operation_id 
    AND fo.federation_operation_type='ALTER FEDERATION SPLIT' 
    AND fom.member_type='SOURCE') fops
ON f.federation_id=fops.federation_id AND fmc.member_id=fops.member_id 
ORDER BY f.name, fmc.range_low, fmc.range_high
GO